@@ -9,7 +9,7 @@
  */
 
 require_once(dirname(__FILE__) . '/../../globals.php');
-require_once($GLOBALS["srcdir"] . "/api.inc");
+require_once($GLOBALS["srcdir"] . "/api.inc.php");
 
 function dap_report($pid, $encounter, $cols, $id)
 {
