@@ -23,7 +23,7 @@
 
 
 require_once('../globals.php');
-require_once($GLOBALS['srcdir'] . '/patient.inc');
+require_once($GLOBALS['srcdir'] . '/patient.inc.php');
 require_once($GLOBALS['srcdir'] . '/options.inc.php');
 require_once($GLOBALS['fileroot'] . '/custom/code_types.inc.php');
 // This determines if a particular procedure code corresponds to receipts
@@ -37,6 +37,7 @@ require_once('../forms/fee_sheet/codes.php');
 use OpenEMR\Common\Acl\AclMain;
 use OpenEMR\Common\Csrf\CsrfUtils;
 use OpenEMR\Common\Twig\TwigContainer;
+use OpenEMR\Common\Utils\FormatMoney;
 use OpenEMR\Core\Header;
 
 if (!AclMain::aclCheckCore('acct', 'rep') && !AclMain::aclCheckCore('acct', 'rep_a')) {
@@ -59,13 +60,6 @@ function is_clinic($code)
     );
 }
 
-function bucks($amount)
-{
-    if ($amount) {
-        echo attr(oeFormatMoney($amount));
-    }
-}
-
 $form_use_edate  = $_POST['form_use_edate'] ?? null;
 
 $form_proc_codefull = trim($_POST['form_proc_codefull'] ?? '');
@@ -633,11 +627,11 @@ $form_facility   = $_POST['form_facility'] ?? null;
                                     <?php echo xlt('Totals for ') . text($docname) ?>
                 </td>
                 <td align="right">
-                                    <?php bucks($doctotal1) ?>
+                                    <?php echo text(FormatMoney::getBucks($doctotal1)) ?>
                 </td>
                                     <?php if ($form_procedures) { ?>
                 <td align="right">
-                                        <?php bucks($doctotal2) ?>
+                                        <?php echo text(FormatMoney::getBucks($doctotal2)) ?>
                 </td>
                     <?php } ?>
                 </tr>
@@ -674,9 +668,9 @@ $form_facility   = $_POST['form_facility'] ?? null;
                                         echo "  <td class='detail' align='right'>";
                                         list($patient_id, $encounter_id) = explode(".", $row['invnumber']);
                                         $tmp = sqlQuery("SELECT SUM(fee) AS sum FROM billing WHERE " .
-                                        "pid = ? AND encounter = ? AND " .
-                                        "code_type = ? AND code = ? AND activity = 1", array($patient_id,$encounter_id,$form_proc_codetype,$form_proc_code));
-                                        bucks($tmp['sum']);
+                                            "pid = ? AND encounter = ? AND " .
+                                            "code_type = ? AND code = ? AND activity = 1", array($patient_id,$encounter_id,$form_proc_codetype,$form_proc_code));
+                                        echo text(FormatMoney::getBucks($tmp['sum']));
                                         echo "  </td>\n";
                                 }
                                 ?>
@@ -692,11 +686,11 @@ $form_facility   = $_POST['form_facility'] ?? null;
                 </td>
                             <?php } ?>
                 <td class="detail" align="right">
-                                <?php bucks($amount1) ?>
+                                <?php echo text(FormatMoney::getBucks($amount1)) ?>
                 </td>
                                 <?php if ($form_procedures) { ?>
                 <td class="detail" align="right">
-                                    <?php bucks($amount2) ?>
+                                    <?php echo text(FormatMoney::getBucks($amount2)) ?>
                 </td>
                             <?php } ?>
                 </tr>
@@ -718,11 +712,11 @@ $form_facility   = $_POST['form_facility'] ?? null;
                         <?php echo xlt('Totals for ') . text($docname ?? '') ?>
                 </td>
                 <td align="right">
-                        <?php bucks($doctotal1 ?? '') ?>
+                        <?php echo text(FormatMoney::getBucks($doctotal1 ?? '')) ?>
                 </td>
                         <?php if ($form_procedures) { ?>
                 <td align="right">
-                            <?php bucks($doctotal2) ?>
+                            <?php echo text(FormatMoney::getBucks($doctotal2)) ?>
                 </td>
                 <?php } ?>
                 </tr>
@@ -733,11 +727,11 @@ $form_facility   = $_POST['form_facility'] ?? null;
                         <?php echo xlt('Grand Totals') ?>
                 </td>
                 <td align="right">
-                        <?php bucks($grandtotal1 ?? '') ?>
+                        <?php echo text(FormatMoney::getBucks($grandtotal1 ?? '')) ?>
                 </td>
                         <?php if ($form_procedures) { ?>
                 <td align="right">
-                            <?php bucks($grandtotal2) ?>
+                            <?php echo text(FormatMoney::getBucks($grandtotal2)) ?>
                 </td>
                 <?php } ?>
                 </tr>
