@@ -34,7 +34,7 @@
 set_time_limit(0);
 require_once("../globals.php");
 require_once("$srcdir/layout.inc.php");
-require_once("$srcdir/patient.inc");
+require_once("$srcdir/patient.inc.php");
 
 use OpenEMR\Common\Acl\AclMain;
 use OpenEMR\Common\Csrf\CsrfUtils;
@@ -116,8 +116,8 @@ $TMP_BASE = $GLOBALS['temporary_files_dir'] . "/openemr_web_backup";
 $BACKUP_DIR = $TMP_BASE . "/emr_backup";
 $TAR_FILE_PATH = $TMP_BASE . DIRECTORY_SEPARATOR . $backup_file_prefix . $backup_file_suffix;
 $EXPORT_FILE = $GLOBALS['temporary_files_dir'] . "/openemr_config.sql";
-$MYSQL_PATH = $GLOBALS['mysql_bin_dir'];
-$PERL_PATH = $GLOBALS['perl_bin_dir'];
+$MYSQL_PATH = realpath($GLOBALS['mysql_bin_dir']);
+$PERL_PATH = realpath($GLOBALS['perl_bin_dir']);
 
 if ($form_step == 6) {
     header("Pragma: public");
@@ -500,8 +500,8 @@ if ($form_step == 0) {
 }
 
 if ($form_step == 1) {
-    $form_status .= xla('Dumping OpenEMR database') . "...<br />";
-    echo nl2br($form_status);
+    $form_status .= xl('Dumping OpenEMR database') . "...||br-placeholder||";
+    echo brCustomPlaceholder(text($form_status));
     if (file_exists($TAR_FILE_PATH)) {
         if (! unlink($TAR_FILE_PATH)) {
             die(xlt("Couldn't remove old backup file:") . " " . text($TAR_FILE_PATH));
@@ -546,8 +546,8 @@ if ($form_step == 2) {
 }
 
 if ($form_step == 3) {
-    $form_status .= xla('Dumping OpenEMR web directory tree') . "...<br />";
-    echo nl2br($form_status);
+    $form_status .= xl('Dumping OpenEMR web directory tree') . "...||br-placeholder||";
+    echo brCustomPlaceholder(text($form_status));
     $cur_dir = getcwd();
     chdir($webserver_root);
 
@@ -588,8 +588,8 @@ if ($form_step == 4) {
 }
 
 if ($form_step == 5) {   // create the final compressed tar containing all files
-    $form_status .= xla('Backup file has been created. Will now send download.') . "<br />";
-    echo nl2br($form_status);
+    $form_status .= xl('Backup file has been created. Will now send download.') . "||br-placeholder||";
+    echo brCustomPlaceholder(text($form_status));
     $cur_dir = getcwd();
     chdir($BACKUP_DIR);
     $file_list = array('.');
@@ -693,8 +693,8 @@ if ($form_step == 102) {
     }
 
     if ($tables || is_array($_POST['form_sel_lists'] ?? '') || is_array($_POST['form_sel_layouts'] ?? '')) {
-        $form_status .= xla('Creating export file') . "...<br />";
-        echo nl2br($form_status);
+        $form_status .= xl('Creating export file') . "...||br-placeholder||";
+        echo brCustomPlaceholder(text($form_status));
         if (file_exists($EXPORT_FILE)) {
             if (! unlink($EXPORT_FILE)) {
                 die(xlt("Couldn't remove old export file: ") . text($EXPORT_FILE));
@@ -825,13 +825,13 @@ if ($form_step == 102) {
                 // Beware and keep in mind that Windows requires double quotes around arguments.
                 if (IS_WINDOWS) {
                     # windows will place the quotes in the outputted code if they are there. we removed them here.
-                    $cmd .= " echo 'DELETE FROM layout_options WHERE form_id = \"" . add_escape_custom($layoutid) . "\";' >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= " echo DELETE FROM layout_options WHERE form_id = \"" . add_escape_custom($layoutid) . "\"; >> " . escapeshellarg($EXPORT_FILE) . " & ";
                 } else {
                     $cmd .= "echo 'DELETE FROM layout_options WHERE form_id = \"" . add_escape_custom($layoutid) . "\";' >> " . escapeshellarg($EXPORT_FILE) . ";";
                 }
                 if (IS_WINDOWS) {
                     # windows will place the quotes in the outputted code if they are there. we removed them here.
-                    $cmd .= "echo 'DELETE FROM layout_group_properties WHERE grp_form_id = \"" . add_escape_custom($layoutid) . "\";' >> " . escapeshellarg($EXPORT_FILE) . " &;";
+                    $cmd .= "echo DELETE FROM layout_group_properties WHERE grp_form_id = \"" . add_escape_custom($layoutid) . "\"; >> " . escapeshellarg($EXPORT_FILE) . " &;";
                 } else {
                     $cmd .= "echo 'DELETE FROM layout_group_properties WHERE grp_form_id = \"" . add_escape_custom($layoutid) . "\";' >> " . escapeshellarg($EXPORT_FILE) . ";";
                 }
@@ -860,34 +860,66 @@ if ($form_step == 102) {
                 }
             }
             // If any HIS* layouts were exported then also write SQL to add missing history_data columns.
-            if ($do_history_repair) {
-                $cmd .= "echo \"SET sql_mode = '';\"                  >> $EXPORT_FILE;";
-                $cmd .= "echo \"SET group_concat_max_len = 1000000;\" >> $EXPORT_FILE;";
-                $cmd .= "echo \"SELECT CONCAT(\"                      >> $EXPORT_FILE;";
-                $cmd .= "echo \"'ALTER TABLE history_data ',\"        >> $EXPORT_FILE;";
-                $cmd .= "echo \"COALESCE(GROUP_CONCAT(DISTINCT ' ADD \`', lo.field_id, '\` TEXT NOT NULL' ORDER BY lo.field_id), '')\" >> $EXPORT_FILE;";
-                $cmd .= "echo \")\"                                   >> $EXPORT_FILE;";
-                $cmd .= "echo \"FROM layout_options AS lo WHERE\"     >> $EXPORT_FILE;";
-                $cmd .= "echo \"(lo.form_id LIKE 'HIS%' OR lo.source = 'H') AND lo.field_id NOT IN\" >> $EXPORT_FILE;";
-                $cmd .= "echo \"(SELECT COLUMN_NAME FROM information_schema.COLUMNS WHERE TABLE_NAME = 'history_data')\" >> $EXPORT_FILE;";
-                $cmd .= "echo \"INTO @sql;\"                          >> $EXPORT_FILE;";
-                $cmd .= "echo \"PREPARE stmt FROM @sql;\"             >> $EXPORT_FILE;";
-                $cmd .= "echo \"EXECUTE stmt;\"                       >> $EXPORT_FILE;";
-            }
-            // If the DEM layout was exported then also write SQL to add missing patient_data columns.
-            if ($do_demographics_repair) {
-                $cmd .= "echo \"SET sql_mode = '';\"                  >> $EXPORT_FILE;";
-                $cmd .= "echo \"SET group_concat_max_len = 1000000;\" >> $EXPORT_FILE;";
-                $cmd .= "echo \"SELECT CONCAT(\"                      >> $EXPORT_FILE;";
-                $cmd .= "echo \"'ALTER TABLE patient_data ',\"        >> $EXPORT_FILE;";
-                $cmd .= "echo \"COALESCE(GROUP_CONCAT(DISTINCT ' ADD \`', lo.field_id, '\` TEXT NOT NULL' ORDER BY lo.field_id), '')\" >> $EXPORT_FILE;";
-                $cmd .= "echo \")\"                                   >> $EXPORT_FILE;";
-                $cmd .= "echo \"FROM layout_options AS lo WHERE\"     >> $EXPORT_FILE;";
-                $cmd .= "echo \"(lo.form_id LIKE 'DEM%' OR lo.source = 'D') AND lo.field_id NOT IN\" >> $EXPORT_FILE;";
-                $cmd .= "echo \"(SELECT COLUMN_NAME FROM information_schema.COLUMNS WHERE TABLE_NAME = 'patient_data')\" >> $EXPORT_FILE;";
-                $cmd .= "echo \"INTO @sql;\"                          >> $EXPORT_FILE;";
-                $cmd .= "echo \"PREPARE stmt FROM @sql;\"             >> $EXPORT_FILE;";
-                $cmd .= "echo \"EXECUTE stmt;\"                       >> $EXPORT_FILE;";
+            if (!IS_WINDOWS) {
+                if ($do_history_repair) {
+                    $cmd .= "echo \"SET sql_mode = '';\"                  >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"SET group_concat_max_len = 1000000;\" >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"SELECT CONCAT(\"                      >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"'ALTER TABLE history_data ',\"        >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"COALESCE(GROUP_CONCAT(DISTINCT ' ADD \`', lo.field_id, '\` TEXT NOT NULL' ORDER BY lo.field_id), '')\" >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \")\"                                   >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"FROM layout_options AS lo WHERE\"     >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"(lo.form_id LIKE 'HIS%' OR lo.source = 'H') AND lo.field_id NOT IN\" >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"(SELECT COLUMN_NAME FROM information_schema.COLUMNS WHERE TABLE_NAME = 'history_data')\" >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"INTO @sql;\"                          >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"PREPARE stmt FROM @sql;\"             >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"EXECUTE stmt;\"                       >> " . escapeshellarg($EXPORT_FILE) . ";";
+                }
+                // If the DEM layout was exported then also write SQL to add missing patient_data columns.
+                if ($do_demographics_repair) {
+                    $cmd .= "echo \"SET sql_mode = '';\"                  >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"SET group_concat_max_len = 1000000;\" >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"SELECT CONCAT(\"                      >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"'ALTER TABLE patient_data ',\"        >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"COALESCE(GROUP_CONCAT(DISTINCT ' ADD \`', lo.field_id, '\` TEXT NOT NULL' ORDER BY lo.field_id), '')\" >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \")\"                                   >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"FROM layout_options AS lo WHERE\"     >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"(lo.form_id LIKE 'DEM%' OR lo.source = 'D') AND lo.field_id NOT IN\" >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"(SELECT COLUMN_NAME FROM information_schema.COLUMNS WHERE TABLE_NAME = 'patient_data')\" >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"INTO @sql;\"                          >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"PREPARE stmt FROM @sql;\"             >> " . escapeshellarg($EXPORT_FILE) . ";";
+                    $cmd .= "echo \"EXECUTE stmt;\"                       >> " . escapeshellarg($EXPORT_FILE) . ";";
+                }
+            } else {
+                if ($do_history_repair) {
+                    $cmd .= "echo SET sql_mode = ''; >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo SET group_concat_max_len = 1000000; >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo SELECT CONCAT( >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo 'ALTER TABLE history_data ' , >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo COALESCE(GROUP_CONCAT(DISTINCT ' ADD `', lo.field_id, '` TEXT NOT NULL' ORDER BY lo.field_id), '') >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo ) >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo FROM layout_options AS lo WHERE >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo (lo.form_id LIKE 'HIS%' OR lo.source = 'H') AND lo.field_id NOT IN >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo (SELECT COLUMN_NAME FROM information_schema.COLUMNS WHERE TABLE_NAME = 'history_data') >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo INTO @sql; >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo PREPARE stmt FROM @sql; >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo EXECUTE stmt; >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                }
+                // If the DEM layout was exported then also write SQL to add missing patient_data columns.
+                if ($do_demographics_repair) {
+                    $cmd .= "echo SET sql_mode = '';                  >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo SET group_concat_max_len = 1000000; >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo SELECT CONCAT(                      >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo 'ALTER TABLE patient_data ',        >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo COALESCE(GROUP_CONCAT(DISTINCT ' ADD `', lo.field_id, '` TEXT NOT NULL' ORDER BY lo.field_id), '') >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo )                                   >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo FROM layout_options AS lo WHERE     >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo (lo.form_id LIKE 'DEM%' OR lo.source = 'D') AND lo.field_id NOT IN >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo (SELECT COLUMN_NAME FROM information_schema.COLUMNS WHERE TABLE_NAME = 'patient_data') >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo INTO @sql;                          >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo PREPARE stmt FROM @sql;             >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                    $cmd .= "echo EXECUTE stmt;                       >> " . escapeshellarg($EXPORT_FILE) . " & ";
+                }
             }
         }
     } else {
@@ -899,8 +931,8 @@ if ($form_step == 102) {
 }
 
 if ($form_step == 103) {
-    $form_status .= xla('Done.  Will now send download.') . "<br />";
-    echo nl2br($form_status);
+    $form_status .= xl('Done.  Will now send download.') . "||br-placeholder||";
+    echo brCustomPlaceholder(text($form_status));
     $auto_continue = true;
 }
 
@@ -919,8 +951,8 @@ if ($form_step == 202) {
   // Process uploaded config file.
     if (is_uploaded_file($_FILES['userfile']['tmp_name'])) {
         if (move_uploaded_file($_FILES['userfile']['tmp_name'], $EXPORT_FILE)) {
-            $form_status .= xla('Applying') . "...<br />";
-            echo nl2br($form_status);
+            $form_status .= xl('Applying') . "...||br-placeholder||";
+            echo brCustomPlaceholder(text($form_status));
             $cmd = escapeshellcmd($mysql_cmd) . " -u " . escapeshellarg($sqlconf["login"]) .
             " -p" . escapeshellarg($sqlconf["pass"]) .
             " -h " . escapeshellarg($sqlconf["host"]) .
@@ -941,8 +973,8 @@ if ($form_step == 202) {
 }
 
 if ($form_step == 203) {
-    $form_status .= xla('Done') . ".";
-    echo nl2br($form_status);
+    $form_status .= xl('Done') . ".";
+    echo brCustomPlaceholder(text($form_status));
 }
 
 /// ViSolve : EventLog Backup
@@ -1026,7 +1058,7 @@ if ($form_step == 405) {
 </table>
 
 <input type='hidden' name='form_step' value='<?php echo attr($form_step); ?>' />
-<input type='hidden' name='form_status' value='<?php echo $form_status; ?>' />
+<input type='hidden' name='form_status' value='<?php echo attr($form_status); ?>' />
 
 </form>
 
@@ -1090,6 +1122,13 @@ if ($file_to_compress) {
 </script>
 <?php }
 
+// convert ||br-placeholder|| to <br>
+// (this is because the nl2br was not working for a reason I couldn't figure out)
+function brCustomPlaceholder(string $str): string
+{
+    return str_replace("||br-placeholder||", "<br />", $str);
+}
+
 // Recursive directory remove (like an O/S insensitive "rm -rf dirname")
 function obliterate_dir($dir)
 {
