@@ -26,7 +26,6 @@ use Installer\Model\InstModuleTable;
 use Laminas\Db\Adapter\Adapter;
 use OpenEMR\Common\Acl\AclMain;
 use OpenEMR\Common\Utils\RandomGenUtils;
-use Laminas\Console\Request as ConsoleRequest;
 use OpenEMR\Services\Utils\SQLUpgradeService;
 
 class InstallerController extends AbstractActionController
@@ -121,19 +120,7 @@ class InstallerController extends AbstractActionController
             }
             die($status ? $this->listenerObject->z_xlt("Success") : $this->listenerObject->z_xlt("Failure"));
         } else {
-            $moduleType = $request->getParam('mtype');
-            $moduleName = $request->getParam('modname');
-            if ($moduleType == 'zend') {
-                $rel_path = "public/" . $moduleName . "/";
-                // registering the table inserts the module record into the database.
-                // it's always loaded regardless, but it inserts it in the database as not activated
-                if ($this->getInstallerTable()->register($moduleName, $rel_path, 0, $GLOBALS['zendModDir'])) {
-                    $status = true;
-                }
-                die($status ? $this->listenerObject->z_xlt("Success") : $this->listenerObject->z_xlt("Failure"));
-            } else {
-                die("not supported");
-            }
+            die("Something went very wrong, so exiting");
         }
     }
 
@@ -281,11 +268,11 @@ class InstallerController extends AbstractActionController
         //INSERT MODULE HOOKS IF NOT EXISTS
         $moduleDirectory = $this->getInstallerTable()->getModuleDirectory($modId);
         //GET MODULE HOOKS FROM A FUNCTION IN CONFIGURATION MODEL CLASS
-        $hooksArr = $this->getInstallerTable()->getModuleHooks($moduleDirectory);
+        $hooksArr = $this->getInstallerTable()->getModuleHooks($moduleDirectory) ?: [];
 
         if (count($hooksArr) > 0) {
             foreach ($hooksArr as $hook) {
-                if (count($hook) > 0) {
+                if (count($hook ?? []) > 0) {
                     if ($this->getInstallerTable()->checkModuleHookExists($modId, $hook['name']) == "0") {
                         $this->getInstallerTable()->saveModuleHooks($modId, $hook['name'], $hook['title'], $hook['path']);
                     }
@@ -327,7 +314,7 @@ class InstallerController extends AbstractActionController
             'ListActiveUsers' => $this->getInstallerTable()->getActiveUsers(),
             'ListActiveACL' => $this->getInstallerTable()->getActiveACL($modId),
             'ListActiveHooks' => $this->getInstallerTable()->getActiveHooks($modId),
-            'helperObject' => $this->helperObject,
+            'helperObject' => $this->helperObject ?? null,
             'configuration' => $configuration,
             'hangers' => $this->getInstallerTable()->getHangers(),
             'Hooks' => $hooksArr,
@@ -388,7 +375,9 @@ class InstallerController extends AbstractActionController
         //SQL version of Module
         $dirModule = $this->getInstallerTable()->getRegistryEntry($modId, "mod_directory");
         $ModulePath = $GLOBALS['srcdir'] . "/../" . $GLOBALS['baseModDir'] . "zend_modules/module/" . $dirModule->modDirectory;
-
+        if (!is_dir($ModulePath)) {
+            $ModulePath = $GLOBALS['srcdir'] . "/../" . $GLOBALS['baseModDir'] . "custom_modules/" . $dirModule->modDirectory;
+        }
         $version_of_module = $ModulePath . "/version.php";
         $table_sql = $ModulePath . "/table.sql";
         $install_sql = $ModulePath . "/sql/install.sql";
@@ -437,6 +426,13 @@ class InstallerController extends AbstractActionController
         if (!is_dir($sqldir)) {
             $sqldir = $ModulePath;
         }
+        if (!is_dir($sqldir)) {
+            $ModulePath = $GLOBALS['srcdir'] . "/../" . $GLOBALS['baseModDir'] . "custom_modules/" . $dirModule->modDirectory;
+            $sqldir = $ModulePath . "/sql";
+            if (!is_dir($sqldir)) {
+                $sqldir = $ModulePath;
+            }
+        }
         $mod->sql_action = "";
 
         if (file_exists($sqldir . "/install.sql") && file_exists($ModulePath . "/version.php") && empty($mod->sql_version)) {
@@ -444,7 +440,7 @@ class InstallerController extends AbstractActionController
         }
 
         if (!empty($mod->sql_version) && $mod->sqlRun == 1) {
-            $versions = $this->getFilesForUpgrade($mod->modDirectory, $sqldir);
+            $versions = $this->getFilesForUpgrade($mod->modDirectory, $sqldir) ?: [];
 
             if (count($versions) > 0) {
                 foreach ($versions as $version => $sfname) {
@@ -574,7 +570,7 @@ class InstallerController extends AbstractActionController
                     $div[] = $string;
                     $add_query_string++;
                 }
-                if (count($matches[1]) == (count($div) - $add_ended_divs) && (!$prev_html_tag && !$curr_html_tag)) {
+                if (count($matches[1]) == (count($div ?? []) - $add_ended_divs) && (!$prev_html_tag && !$curr_html_tag)) {
                     $div[] = "</div>";
                 }
                 $k++;
@@ -639,7 +635,7 @@ class InstallerController extends AbstractActionController
         $resp = $this->getInstallerTable()->updateRegistered($modId, "mod_active=1");
         if ($resp['status'] == 'failure' && $resp['code'] == '200') {
             $plural = "Module";
-            if (count($resp['value']) > 1) {
+            if (count($resp['value'] ?? []) > 1) {
                 $plural = "Modules";
             }
 
@@ -672,7 +668,7 @@ class InstallerController extends AbstractActionController
                 // TODO: This is a wierd error... why is it written like this?
                 $status = $this->listenerObject->z_xlt("ERROR") . ':' . $this->listenerObject->z_xlt("could not open table") . '.' . $this->listenerObject->z_xlt("sql") . ', ' . $this->listenerObject->z_xlt("broken form") . "?";
             }
-        } else if ($modType == InstModuleTable::MODULE_TYPE_ZEND) {
+        } elseif ($modType == InstModuleTable::MODULE_TYPE_ZEND) {
             $fullDirectory = $GLOBALS['srcdir'] . "/../" . $GLOBALS['baseModDir'] . "zend_modules/module/" . $dirModule;
             if ($this->getInstallerTable()->installSQL($modId, $modType, $fullDirectory)) {
                 $sqlInstalled = true;
@@ -746,16 +742,12 @@ class InstallerController extends AbstractActionController
     /**
      *
      */
-    public function commandInstallModuleAction()
+    public function commandInstallModuleAction($moduleName, $moduleAction)
     {
-        $request = $this->getRequest();
-        if (!$request instanceof ConsoleRequest) {
+        if (php_sapi_name() !== 'cli') {
             throw new RuntimeException('You can only use this action from a console!');
         }
 
-        $moduleAction = $request->getParam('modaction');
-        $moduleName = $request->getParam('modname');
-
         $moduleId = null;
         $div = [];
 
