@@ -14,7 +14,7 @@
  */
 
 require_once("../globals.php");
-require_once("$srcdir/patient.inc");
+require_once("$srcdir/patient.inc.php");
 require_once("$srcdir/options.inc.php");
 require_once("../drugs/drugs.inc.php");
 require_once("$srcdir/payment_jav.inc.php");
@@ -54,8 +54,8 @@ $comarr = array
     "allow_email" => xl("Allow Email")
 );
 
-// get array of all insurance companies from function in patient.inc
-$insarr = getInsuranceProviders();
+// get array of all insurance companies from function in patient.inc.php
+$insarr = getInsuranceProvidersExtra();
 
 $_POST['form_details'] = true;
 
