@@ -6,22 +6,28 @@
  * @package   OpenEMR
  * @link      https://www.open-emr.org
  * @author    Jerry Padgett <sjpadgett@gmail.com>
- * @copyright Copyright (c) 2021 Jerry Padgett <sjpadgett@gmail.com>
+ * @copyright Copyright (c) 2021-2022 Jerry Padgett <sjpadgett@gmail.com>
  * @license   https://github.com/openemr/openemr/blob/master/LICENSE GNU General Public License 3
  */
 
 namespace OpenEMR\Services\DocumentTemplates;
 
 use Exception;
+use OpenEMR\Services\QuestionnaireService;
 use RuntimeException;
 
 /**
  *
  */
-class DocumentTemplateService
+class DocumentTemplateService extends QuestionnaireService
 {
-    public function __construct()
+    const DENIAL_STATUS_EDITING = "Editing";
+    const DENIAL_STATUS_IN_REVIEW = "In Review";
+    const DENIAL_STATUS_LOCKED = "Locked";
+
+    public function __construct($base_table = null)
     {
+        parent::__construct($base_table ?? null);
     }
 
     public function uniqueByKey($source, $key): array
@@ -169,24 +175,13 @@ class DocumentTemplateService
     }
 
     /**
-     * @return array
+     * @param     $profile
+     * @param int $tid
+     * @return bool|array|null
      */
-    public function fetchAllProfileEvents(): array
+    public function fetchTemplateEvent($profile, $tid = 0): bool|array|null
     {
-        $result = [];
-        $events = sqlStatement("SELECT `profile`, `recurring`, `event_trigger`, `period` FROM `document_template_profiles` WHERE `template_id` > '0' GROUP BY `profile`");
-        foreach ($events as $event) {
-            $result[$event['profile']] = $event;
-        }
-        return $result;
-    }
-
-    /**
-     * @return array
-     */
-    public function fetchProfileEvents($profile): array
-    {
-        return sqlQuery("SELECT `profile`, `recurring`, `event_trigger`, `period` FROM `document_template_profiles` WHERE `template_id` > '0' AND `profile` = ? GROUP BY `profile` LIMIT 1", array($profile));
+        return sqlQuery("SELECT * FROM `document_template_profiles` WHERE `template_id` = ? AND `profile` = ?", array($tid ?? 0, $profile ?? ''));
     }
 
 
@@ -194,33 +189,37 @@ class DocumentTemplateService
      * @param $template
      * @return mixed int|date
      */
-    public function showTemplateFromEvent($template, $show_due_date = false)
+    public function showTemplateFromEvent($template, $show_due_date = false): mixed
     {
         $in_review = false;
         $result = sqlQuery("SELECT * FROM `onsite_documents` WHERE `pid` = ? AND `file_path` = ? ORDER BY `create_date` DESC LIMIT 1", array($template['pid'], $template['id']));
         if (!$result) {
             return true;
         }
-        $in_review = $result['denial_reason'] === 'Locked' || $result['denial_reason'] === 'In Review';
+        $in_review = $result['denial_reason'] === self::DENIAL_STATUS_LOCKED || $result['denial_reason'] === self::DENIAL_STATUS_IN_REVIEW;
         // must be a saved doc pending review so don't show.
         // patient selects the edited doc from their history.
         if (!$in_review) {
             return false;
         }
-        if (!isset($template['trigger_event'])) {
+        if (!isset($template['event_trigger'])) {
             // these are sent templates. Not in group.
             if (!empty($template['profile'])) {
-                $event = $this->fetchProfileEvents($template['profile']);
+                $event = $this->fetchTemplateEvent($template['profile'], $template['id'] ?? 0);
                 $template['event_trigger'] = '';
-                $template['recurring'] = 1;
                 $template['period'] = 0;
+                $template['recurring'] = 1;
+                $template['notify_trigger'] = '';
+                $template['notify_period'] = 0;
                 if (is_array($event)) {
                     $template['event_trigger'] = $event['event_trigger'];
-                    $template['recurring'] = $event['recurring'];
                     $template['period'] = $event['period'];
+                    $template['recurring'] = $event['recurring'];
+                    $template['notify_trigger'] = $event['notify_trigger'];
+                    $template['notify_period'] = $event['notify_period'];
                 }
             } else {
-                return false; // in review or locked so don't show. @todo possibly delete sent template.
+                return true; // in review or locked so show default template. @todo possibly delete sent template.
             }
         }
         if ($template['event_trigger'] === 'once') {
@@ -297,18 +296,18 @@ class DocumentTemplateService
     }
 
     /**
-     * @param      $id
-     * @param null $template_name
+     * @param mixed $id numeric id or template name
      * @return array|false|null
      */
-    public function fetchTemplate($id, $template_name = null)
+    public function fetchTemplate(mixed $id): bool|array|null
     {
-        $return = null;
-        if (!empty($id)) {
+        $isFetchById = is_numeric($id);
+        if (!empty($id && $isFetchById)) {
             $return = sqlQuery('SELECT * FROM `document_templates` WHERE `id` = ?', array($id));
-        } elseif (!empty($template_name)) {
-            $return = sqlQuery('SELECT * FROM `document_templates` WHERE `template_name` = ?', array($template_name));
+        } else {
+            $return = sqlQuery('SELECT * FROM `document_templates` WHERE `template_name` = ?', array($id));
         }
+
         return $return;
     }
 
@@ -435,14 +434,19 @@ class DocumentTemplateService
     }
 
     /**
-     * @param null $category
-     * @param int  $pid
-     * @return array|null[]
+     * @param null  $category
+     * @param mixed $pid
+     * @return
      */
-    public function getTemplateListByCategory($category = null, $pid = 0): array
+    public function getTemplateListByCategory($category = null, $pid = 0, $name = null): bool|array|null
     {
+        // if pid is -1 then belongs to repository. 0 is default templates else is assigned to patient.
         $results = array($category => null);
-        $query_result = sqlStatement('SELECT * FROM `document_templates` WHERE category = ? AND pid = ?', array($category, $pid));
+        if (empty($name)) {
+            $query_result = sqlStatement('SELECT * FROM `document_templates` WHERE category = ? AND pid = ?', array($category, $pid));
+        } else {
+            return sqlQuery('SELECT * FROM `document_templates` WHERE category = ? AND pid = ? AND template_name = ? LIMIT 1', array($category, $pid, $name));
+        }
         while ($row = sqlFetchArray($query_result)) {
             if (is_array($row)) {
                 $results[$category][] = $row;
@@ -485,46 +489,15 @@ class DocumentTemplateService
         return $results;
     }
 
-// can delete
-
-    /**
-     * @param null $pid
-     * @param null $category
-     * @return array
-     */
-    public function getTemplateCategoriesByPatient($pid = null, $category = null): array
-    {
-        $results = array();
-        $bind = array();
-        if (empty($pid)) {
-            $where = 'WHERE pid > ?';
-            $bind = array($pid ?? 0);
-        } else {
-            $where = 'WHERE pid = ?';
-            $bind = array($pid);
-        }
-        if (!empty($category)) {
-            $where .= ' AND category = ?';
-            $bind[] = $category;
-        }
-        $sql = "SELECT * FROM `document_templates` $where ORDER BY pid, category";
-        $query_result = sqlStatement($sql, $bind);
-        while ($row = sqlFetchArray($query_result)) {
-            if (is_array($row)) {
-                $results[$row['category']][] = $row;
-            }
-        }
-        return $results;
-    }
-
     /**
      * @param       $template_name
      * @param       $category
      * @param       $file
      * @param array $pids
      * @return int
+     * @throws Exception
      */
-    public function uploadTemplate($template_name, $category, $file, $pids = []): int
+    public function uploadTemplate($template_name, $category, $file, $pids = [], $q_only = false): int
     {
         $mimetype = null;
         if (function_exists('finfo_open')) {
@@ -540,7 +513,29 @@ class DocumentTemplateService
         }
 
         $content = file_get_contents($file);
+
         $id = 0;
+        $q_ob = json_decode($content, true); // only pass array
+        $is_json = json_last_error() === JSON_ERROR_NONE;
+        if ($is_json) {
+            if (($q_ob['resourceType'] ?? '') != 'Questionnaire') {
+                throw new Exception(xlt("Not a valid Questionnaire resource!"));
+            }
+            if (empty($category)) {
+                $category = 'questionnaire';
+            }
+            $template_name = $template_name ?: $q_ob['title'] ?? $q_ob['name'];
+            $q_id = null;
+            $content = "{Questionnaire:$template_name}" . "\n";
+            $mimetype = 'application/text';
+            $service = new QuestionnaireService();
+            $id = $service->saveQuestionnaireResource(json_encode($q_ob), $template_name, null, $q_id, null);
+            if (empty($id)) {
+                return $id;
+            } elseif ($q_only) {
+                return $id;
+            }
+        }
         foreach ($pids as $pid) {
             $id = $this->insertTemplate($pid, $category, $template_name, $content, $mimetype);
         }
@@ -570,9 +565,9 @@ class DocumentTemplateService
             $name = 'Repository';
         }
 
-        $sql = "INSERT INTO `document_templates` 
-            (`pid`, `provider`,`profile`, `category`, `template_name`, `location`, `status`, `template_content`, `size`, `mime`) 
-            VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?) 
+        $sql = "INSERT INTO `document_templates`
+            (`pid`, `provider`,`profile`, `category`, `template_name`, `location`, `status`, `template_content`, `size`, `mime`)
+            VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
             ON DUPLICATE KEY UPDATE `pid` = ?, `provider`= ?, `template_content`= ?, `size`= ?, `modified_date` = NOW(), `mime` = ?";
 
         return sqlInsert($sql, array($pid, ($_SESSION['authUserID'] ?? null), ($profile ?: ''), $category ?: '', $template, $name, 'New', $content, strlen($content), $mimetype, $pid, ($_SESSION['authUserID'] ?? null), $content, strlen($content), $mimetype));
@@ -735,11 +730,11 @@ class DocumentTemplateService
                     $form_data[$form['name']] = trim($form['value'] ?? '');
                 }
                 $rtn = sqlInsert(
-                    "INSERT INTO `document_template_profiles` 
-            (`template_id`, `profile`, `template_name`, `category`, `provider`, `recurring`, `event_trigger`, `period`) VALUES (?, ?, ?, ?, ?, ?, ?, ?)",
+                    "INSERT INTO `document_template_profiles`
+            (`template_id`, `profile`, `template_name`, `category`, `provider`, `recurring`, `event_trigger`, `period`, `notify_trigger`, `notify_period`) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)",
                     array($profile_array['id'], $profile_array['profile'],
                         $profile_array['name'], $profile_array['category'], ($_SESSION['authUserID'] ?? null),
-                        $form_data['recurring'] ? 1 : 0, $form_data['when'], $form_data['days'])
+                        $form_data['recurring'] ? 1 : 0, $form_data['when'] ?? '', $form_data['days'] ?? '', $form_data['notify_when'] ?? '', $form_data['notify_days'] ?? '')
                 );
             }
         } catch (Exception $e) {
@@ -770,11 +765,7 @@ class DocumentTemplateService
     {
         $rtn = sqlStatement('SELECT `option_id`, `title`, `seq` FROM `list_options` WHERE `list_id` = ? ORDER BY `seq`', array('Document_Template_Categories'));
         $category_list = array();
-        $category_list[''] = array(
-            'option_id' => '',
-            'title' => '',
-            'seq' => '',
-        );
+
         $category_list['General'] = array(
             'option_id' => '',
             'title' => '',
@@ -814,21 +805,32 @@ class DocumentTemplateService
 
 
     /**
-     * @param $pid
-     * @param $id
+     * Return patient current document status for document stages.
+     *
+     * @param      $pid
+     * @param      $name
+     * @param bool $return_content
      * @return array|false|null
      */
-    public function fetchTemplateStatus($pid, $name)
+    public function fetchPatientDocumentStatus($pid, $name, bool $return_content = false): bool|array|null
     {
-        $sql = "SELECT `pid`, `create_date`, `doc_type`, `patient_signed_time`, `authorize_signed_time`, `patient_signed_status`, `review_date`, `denial_reason`, `file_name`, `file_path` FROM `onsite_documents` WHERE `pid` = ? AND `file_path` = ? ORDER BY `create_date` DESC LIMIT 1";
-        return sqlQuery($sql, array($pid, $name));
+        $sql = "SELECT od.id AS audit_id, od.pid, od.create_date, od.doc_type, od.*, oa.* FROM onsite_documents as od" .
+            " LEFT JOIN `onsite_portal_activity` AS oa ON od.id = oa.id AND od.doc_type = oa.narrative" .
+            " WHERE od.pid = ? AND od.file_path = ? ORDER BY od.create_date DESC LIMIT 1";
+
+        $q = sqlQuery($sql, array($pid, $name));
+        if ($q && !$return_content) {
+            $q['full_document'] = null;
+            $q["template_data"] = null;
+        }
+        return $q;
     }
 
     /**
      * @param $profile
      * @return mixed
      */
-    public function fetchProfileStatus($profile)
+    public function fetchProfileStatus($profile): mixed
     {
         return sqlQuery('SELECT active FROM `document_template_profiles` WHERE `template_id` = "0" AND `profile` = ?', array($profile))['active'];
     }
@@ -874,7 +876,8 @@ class DocumentTemplateService
                     if ((int)$template['pid'] === 0) {
                         $template['pid'] = $current_patient;
                     }
-                    $in_edit = sqlQuery("Select `id`, `doc_type`, `denial_reason` From `onsite_documents` Where (`denial_reason` = 'Editing' Or `denial_reason` = 'In Review') And `pid` = ? And `file_path` = ? Limit 1", array($template['pid'], $template['id'])) ?? 0;
+                    $in_edit = sqlQuery("Select `id`, `doc_type`, `denial_reason` From `onsite_documents` Where (`denial_reason` = '"
+                        . self::DENIAL_STATUS_EDITING . "' Or `denial_reason` = '" . self::DENIAL_STATUS_IN_REVIEW . "') And `pid` = ? And `file_path` = ? Limit 1", array($template['pid'], $template['id'])) ?? 0;
                     if (empty($in_edit)) {
                         $test = $this->showTemplateFromEvent($template);
                         if (!$test) {
@@ -894,7 +897,8 @@ class DocumentTemplateService
                     $id = $template['id'];
                     $btnname = $template['template_name'];
                     if (!empty($in_edit)) {
-                        $menu .= '<a class="dropdown-item template-item text-danger btn btn-link" id="' . attr($id) . '"' . ' href="#" onclick="page.editHistoryDocument(' . attr_js($in_edit['id']) . ')">' . text($btnname) . "</a>\n";
+                        $menu .= '<a class="dropdown-item template-item text-primary btn btn-link font-weight-bold" id="' . attr($id) . '"' .
+                            ' data-history_id="' . attr($in_edit['id']) . '"' . ' href="#" onclick="page.editHistoryDocument(' . attr_js($in_edit['id']) . ')">' . text($btnname) . "</a>\n";
                     } else {
                         $menu .= '<a class="dropdown-item template-item text-success btn btn-link" id="' . attr($id) . '"' . ' href="#" onclick="page.newDocument(' . attr_js($current_patient) . ', ' . attr_js($current_user) . ', ' . attr_js($btnname) . ', ' . attr_js($id) . ')">' . text($btnname) . "</a>\n";
                     }
